@@ -11,7 +11,7 @@ class GCSWriter():
 
     def __init__(self):
         if self.GOOGLE_APPLICATION_CREDENTIALS:
-            self.client = Client.from_service_account_json(self.GOOGLE_APPLICATION_CREDENTIALS)
+            self.client = Client.from_service_account_info(self.GOOGLE_APPLICATION_CREDENTIALS)
         else:
             raise ConnectionError("Make sure the env variable \"GOOGLE_APPLICATION_CREDENTIALS\" exists")
 
